@@ -1,44 +1,12 @@
-import ast
-import json
 
-import requests
+from flask import jsonify, make_response
 from foqus.mqueue import *
 
-import logging
-import coloredlogs
+
+import ast
+import json
+import requests
 import time
-from flask import jsonify, make_response
-
-if USE_LOG_AZURE:
-
-    from azure_storage_logging.handlers import TableStorageHandler
-
-    # configure the handler and add it to the logger
-    logger = logging.getLogger(__name__)
-    handler = TableStorageHandler(account_name=LOG_AZURE_ACCOUNT_NAME,
-                                  account_key=LOG_AZURE_ACCOUNT_KEY,
-                                  extra_properties=('%(hostname)s',
-                                                    '%(levelname)s'))
-    logger.setLevel(logging.DEBUG)
-    logger.addHandler(handler)
-else:
-
-    logger = logging.getLogger(__name__)
-    coloredlogs.install()
-    logger.setLevel(logging.DEBUG)
-    # create file handler which logs even debug messages
-    fh = logging.FileHandler(LOG_PATH + 'trynfit_debug.log')
-    fh.setLevel(logging.DEBUG)
-    # create console handler with a higher log level
-    ch = logging.StreamHandler()
-    ch.setLevel(logging.ERROR)
-    # create formatter and add it to the handlers
-    formatter = logging.Formatter('[%(asctime)s] %(levelname)s [%(name)s:%(lineno)s] %(message)s', '%d/%b/%Y %H:%M:%S')
-    ch.setFormatter(formatter)
-    fh.setFormatter(formatter)
-    # add the handlers to logger
-    logger.addHandler(ch)
-    logger.addHandler(fh)
 
 
 def timeit(method):
@@ -49,16 +17,14 @@ def timeit(method):
         try:
             data = json.loads(result)
             data['log_time'] = (te - ts)
-            logger.info('%r  %2.2f s (try)' % \
-                  (method.__name__, (te - ts)))
-        except:
+            logger.info('%r  %2.2f s (try)' % (method.__name__, (te - ts)))
+        except Exception as e:
             data = {}
             data['data'] = result
             data['log_time'] = (te - ts)
-            logger.info('%r  %2.2f s (except)' % \
-                  (method.__name__, (te - ts)))
+            logger.info('%r  %2.2f s (except)' % (method.__name__, (te - ts)))
 
-        return (data)
+        return data
     return timed
 
 
@@ -75,9 +41,10 @@ def format_to_json_response(response):
     return ast.literal_eval(response_dict)
 
 
-def rest_api_request( server, request_type, user_api_key, operation, customer_name, customer_type, customer_universe,
-                     project_name, body, customer_email, customer_password,type_user,first_name,last_name,phone_number,job,
-               number_of_staff,plan,cms_if_exist,url_cms,new_email,new_password,new_password_verif,subject_of_email,message_email,month_num,ip,token_cms):
+def rest_api_request(server, request_type, user_api_key, operation, customer_name, customer_type, customer_universe,
+                     project_name, body, customer_email, customer_password, type_user, first_name, last_name,
+                     phone_number, job, number_of_staff, plan, cms_if_exist, url_cms, new_email, new_password,
+                     new_password_verif, subject_of_email, message_email, month_num, ip, token_cms):
     try:
         # REST API tests
         s = requests.Session()
@@ -92,22 +59,22 @@ def rest_api_request( server, request_type, user_api_key, operation, customer_na
                 'customer_email': customer_email,
                 'customer_password': customer_password,
                 'type_user': type_user,
-                'first_name':first_name,
-                'last_name':last_name,
-                'phone_number':phone_number,
-                'job':job,
-                'number_of_staff':number_of_staff,
-                'plan':plan,
-                'cms_if_exist':cms_if_exist,
-                'url_cms':url_cms,
-                'new_email':new_email,
-                'new_password':new_password,
-                'new_password_verif':new_password_verif,
-                'subject_of_email':subject_of_email,
-                'message_email':message_email,
+                'first_name': first_name,
+                'last_name': last_name,
+                'phone_number': phone_number,
+                'job': job,
+                'number_of_staff': number_of_staff,
+                'plan': plan,
+                'cms_if_exist': cms_if_exist,
+                'url_cms': url_cms,
+                'new_email': new_email,
+                'new_password': new_password,
+                'new_password_verif': new_password_verif,
+                'subject_of_email': subject_of_email,
+                'message_email': message_email,
                 'body': body,
                 'month_num': month_num,
-                'ip':ip,
+                'ip': ip,
                 'token_cms': token_cms
                 }
 
@@ -139,8 +106,10 @@ def get_similars_if_exist(user_apikey, customer_name, customer_type, project_nam
                                         'ip': ip
                                         },
                                message_body=body)
+        rpc_queue.close()
         return value.decode('utf-8')
 
+
 # api_authentication
 @timeit
 def customer_authentication(customer_email, customer_password, body, type_user):
@@ -157,6 +126,7 @@ def customer_authentication(customer_email, customer_password, body, type_user):
                                     'customer_password': customer_password},
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -173,6 +143,7 @@ def get_api_key_expiration(customer_name, customer_type, user_apikey):
                                     'user_apikey': user_apikey},
                            message_body="")
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -191,6 +162,7 @@ def customer_inscription(customer_email, customer_type, customer_name, body, typ
                                     'user_apikey': ""},
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -222,8 +194,6 @@ def process_customer_stream_cms(user_apikey, customer_name, customer_type, proje
     my_queue_json.publish(body)
 
 
-
-
 def shopify_training(user_apikey, customer_name, customer_type, project_name, body):
     my_queue_json = RabbitMQ(mqueue_address=MESSAGE_QUEUE_ADDRESS,
                              mqueue_port=MESSAGE_QUEUE_PORT,
@@ -254,6 +224,7 @@ def text_training(user_apikey, customer_name, customer_type, customer_universe,
                                     'customer_universe': customer_universe},
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -281,19 +252,6 @@ def image_training(user_apikey, customer_name, customer_type, customer_universe)
     my_queue_json.publish('')
 
 
-#
-# def predict_customer(user_apikey, customer_name, customer_type, customer_universe, body):
-#     my_queue_json = mqueue.RabbitMQ(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
-#                              mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD,
-#                              mqueue_name=MESSAGE_QUEUE_INPUT_NAME,
-#                              headers={'user_apikey': user_apikey,
-#                                       'operation': 'predict_customer',
-#                                       'customer_name': customer_name,
-#                                       'customer_type': customer_type,
-#                                       'customer_universe': customer_universe})
-#     my_queue_json.publish(body)
-
-
 def predict_customer(user_apikey, customer_name, customer_type, customer_universe, body):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
                           mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
@@ -303,7 +261,10 @@ def predict_customer(user_apikey, customer_name, customer_type, customer_univers
                                     'customer_universe': customer_universe,
                                     'customer_type': customer_type},
                            message_body=body)
-    return value.decode('utf-8')
+    value = value.decode('utf-8')
+    rpc_queue.close()
+    return value
+
 
 @timeit
 def predict_image(user_apikey, customer_name, customer_type, body, project_name):
@@ -315,6 +276,7 @@ def predict_image(user_apikey, customer_name, customer_type, body, project_name)
                                     'project_name': project_name,
                                     'customer_type': customer_type},
                            message_body=body)
+    rpc_queue.close()
     return value
 
 
@@ -327,6 +289,7 @@ def detect_missing_images(user_apikey, customer_name, customer_type, project, bo
                                     'project': project,
                                     'customer_type': customer_type},
                            message_body=str(body))
+    rpc_queue.close()
     return value
 
 @timeit
@@ -340,20 +303,21 @@ def get_historic(user_apikey, customer_name, customer_type, body, project_name,
                                     'project_name': project_name,
                                     'month_num': month_num},
                            message_body=body)
-
+    rpc_queue.close()
     return value
 
 
-def process_customer_training_classification(user_apikey, customer_name, customer_type, customer_universe, body, project_name):
+def process_customer_training_classification(user_apikey, customer_name, customer_type, customer_universe, body,
+                                             project_name):
     my_queue_json = RabbitMQ(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
                              mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD,
                              mqueue_name=MESSAGE_QUEUE_INPUT_NAME,
                              headers={'user_apikey': user_apikey,
-                                    'operation': 'process_customer_training_classification',
-                                    'customer_name': customer_name,
-                                    'customer_type': customer_type,
-                                    'project_name': project_name,
-                                    'customer_universe': customer_universe})
+                                      'operation': 'process_customer_training_classification',
+                                      'customer_name': customer_name,
+                                      'customer_type': customer_type,
+                                      'project_name': project_name,
+                                      'customer_universe': customer_universe})
     my_queue_json.publish(body)
 
 
@@ -375,7 +339,7 @@ def get_list_all_clients_with_projects(body):
         'operation': 'get_list_all_clients_with_projects'
     },
         message_body=body)
-
+    rpc_queue.close()
     return value
 
 
@@ -386,7 +350,7 @@ def get_number_post_per_clients(body):
         'operation': 'get_number_post_per_clients'
     },
         message_body=body)
-
+    rpc_queue.close()
     return value
 
 
@@ -401,6 +365,7 @@ def update_user_apikey(customer_name, customer_type, body):
                                     },
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -434,6 +399,7 @@ def get_specified_project_status(user_apikey, customer_name, customer_type, proj
                                     },
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -450,6 +416,7 @@ def get_client_payment_status(customer_name, customer_type):
                            message_body="")
 
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 @timeit
@@ -466,6 +433,7 @@ def get_payment_status_for_client(user_apikey, customer_name, customer_type):
                            message_body="")
 
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -482,6 +450,7 @@ def get_client_statistics(user_apikey, customer_name, customer_type):
                                     },
                            message_body="")
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -495,6 +464,7 @@ def get_statistics_for_admin(customer_name, customer_type):
                                     'customer_type': customer_type},
                            message_body='')
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -507,6 +477,7 @@ def all_historic_users_management(body):
                                     },
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -525,6 +496,7 @@ def get_details_trainings_for_client(user_apikey, customer_name, customer_type,
                            message_body="")
 
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -539,68 +511,71 @@ def get_details_trainings_for_admin(customer_name, customer_type, project_name):
                                     'project_name': project_name},
                            message_body='')
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
 def all_historic_users_management_customer(body):
-  rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                               mqueue_port=MESSAGE_QUEUE_PORT,
-                               mqueue_user=MESSAGE_QUEUE_USER,
-                               mqueue_password=MESSAGE_QUEUE_PASSWORD)
-  value = rpc_queue.call(headers={'operation': 'all_historic_users_management_customer'
-                                  },
-                         message_body=body)
-  value=value.decode('utf-8')
-  return value
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
+                          mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER,
+                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'operation': 'all_historic_users_management_customer'}, message_body=body)
+    value = value.decode('utf-8')
+    rpc_queue.close()
+    return value
 
 
 # api_can_create_users
-def can_create_users(customer_email, body, type_user, type_new_user, email, password,entreprise, nom, prenom,num_tel, domaine):
-  rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                               mqueue_port=MESSAGE_QUEUE_PORT,
-                               mqueue_user=MESSAGE_QUEUE_USER,
-                               mqueue_password=MESSAGE_QUEUE_PASSWORD)
-  value = rpc_queue.call(headers={'customer_email': customer_email,
-                                  'type_user' : type_user,
-                                  'type_new_user': type_new_user,
-                                  'email': email,
-                                  'password' : password,
-                                  'entreprise' : entreprise,
-                                  'nom': nom,
-                                  'prenom': prenom,
-                                  'num_tel': num_tel,
-                                  'domaine': domaine,
-                                  'operation': 'can_create_users',
-                                  'customer_name': "",
-                                  'customer_type': "",
-                                  'user_apikey': ""},
-                         message_body=body)
-  value=value.decode('utf-8')
-  return value
+def can_create_users(customer_email, body, type_user, type_new_user, email, password, entreprise, nom, prenom,
+                     num_tel, domaine):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
+                          mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER,
+                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'customer_email': customer_email,
+                                    'type_user': type_user,
+                                    'type_new_user': type_new_user,
+                                    'email': email,
+                                    'password': password,
+                                    'entreprise': entreprise,
+                                    'nom': nom,
+                                    'prenom': prenom,
+                                    'num_tel': num_tel,
+                                    'domaine': domaine,
+                                    'operation': 'can_create_users',
+                                    'customer_name': "",
+                                    'customer_type': "",
+                                    'user_apikey': ""},
+                           message_body=body)
+    value = value.decode('utf-8')
+    rpc_queue.close()
+    return value
 
 
 def can_delete_users(customer_email, body, type_user, email):
-  rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                               mqueue_port=MESSAGE_QUEUE_PORT,
-                               mqueue_user=MESSAGE_QUEUE_USER,
-                               mqueue_password=MESSAGE_QUEUE_PASSWORD)
-  value = rpc_queue.call(headers={'customer_email': customer_email,
-                                  'type_user' : type_user,
-                                  'email': email,
-                                  'operation': 'can_delete_users',
-                                  'customer_name': "",
-                                  'customer_type': "",
-                                  'user_apikey': ""},
-                         message_body=body)
-  value=value.decode('utf-8')
-  return value
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
+                          mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER,
+                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'customer_email': customer_email,
+                                    'type_user': type_user,
+                                    'email': email,
+                                    'operation': 'can_delete_users',
+                                    'customer_name': "",
+                                    'customer_type': "",
+                                    'user_apikey': ""},
+                           message_body=body)
+    value = value.decode('utf-8')
+    rpc_queue.close()
+    return value
 
 
 def can_edit_users(customer_email, body, type_user, email, password, entreprise, nom, prenom, num_tel, domaine):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                                 mqueue_port=MESSAGE_QUEUE_PORT,
-                                 mqueue_user=MESSAGE_QUEUE_USER,
-                                 mqueue_password=MESSAGE_QUEUE_PASSWORD)
+                          mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER,
+                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
     value = rpc_queue.call(headers={'customer_email': customer_email,
                                     'type_user': type_user,
                                     'email': email,
@@ -616,14 +591,15 @@ def can_edit_users(customer_email, body, type_user, email, password, entreprise,
                                     'user_apikey': ""},
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
 def can_view_users(customer_email, body, type_user):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                                 mqueue_port=MESSAGE_QUEUE_PORT,
-                                 mqueue_user=MESSAGE_QUEUE_USER,
-                                 mqueue_password=MESSAGE_QUEUE_PASSWORD)
+                          mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER,
+                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
     value = rpc_queue.call(headers={'customer_email': customer_email,
                                     'type_user': type_user,
                                     'operation': 'can_view_users',
@@ -632,6 +608,7 @@ def can_view_users(customer_email, body, type_user):
                                     'user_apikey': ""},
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -648,28 +625,30 @@ def can_view_customers(customer_email, body, type_user):
                                     'user_apikey': ""},
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
-def can_update_apikey(customer_email, type_user,email, body):
+def can_update_apikey(customer_email, type_user, email, body):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                                 mqueue_port=MESSAGE_QUEUE_PORT,
-                                 mqueue_user=MESSAGE_QUEUE_USER,
-                                 mqueue_password=MESSAGE_QUEUE_PASSWORD)
+                          mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER,
+                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
     value = rpc_queue.call(headers={'customer_email': customer_email,
                                     'type_user': type_user,
                                     'operation': 'can_update_apikey',
                                     'email': email},
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
-def can_delete_project(customer_email, type_user,customer_name, customer_type, project_name,body):
+def can_delete_project(customer_email, type_user, customer_name, customer_type, project_name, body):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                                 mqueue_port=MESSAGE_QUEUE_PORT,
-                                 mqueue_user=MESSAGE_QUEUE_USER,
-                                 mqueue_password=MESSAGE_QUEUE_PASSWORD)
+                          mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER,
+                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
     value = rpc_queue.call(headers={'customer_email': customer_email,
                                     'type_user': type_user,
                                     'operation': 'can_delete_project',
@@ -678,14 +657,15 @@ def can_delete_project(customer_email, type_user,customer_name, customer_type, p
                                     'customer_type': customer_type},
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
-def creation_entreprise_package(customer_email, type_user, plan_name, total,max_images_training,body):
+def creation_entreprise_package(customer_email, type_user, plan_name, total, max_images_training, body):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                                 mqueue_port=MESSAGE_QUEUE_PORT,
-                                 mqueue_user=MESSAGE_QUEUE_USER,
-                                 mqueue_password=MESSAGE_QUEUE_PASSWORD)
+                          mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER,
+                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
     value = rpc_queue.call(headers={'customer_email': customer_email,
                                     'type_user': type_user,
                                     'operation': 'creation_entreprise_package',
@@ -694,19 +674,21 @@ def creation_entreprise_package(customer_email, type_user, plan_name, total,max_
                                     'max_images_training': max_images_training},
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
-def get_all_plans_payement(customer_email, type_user,body):
+def get_all_plans_payement(customer_email, type_user, body):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                                 mqueue_port=MESSAGE_QUEUE_PORT,
-                                 mqueue_user=MESSAGE_QUEUE_USER,
-                                 mqueue_password=MESSAGE_QUEUE_PASSWORD)
+                          mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER,
+                          mqueue_password=MESSAGE_QUEUE_PASSWORD)
     value = rpc_queue.call(headers={'customer_email': customer_email,
                                     'type_user': type_user,
                                     'operation': 'get_all_plans_payement'},
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -721,8 +703,10 @@ def all_status_projects(customer_name, customer_type, body):
                                     },
                            message_body=body)
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
+
 @timeit
 def all_status_project(user_apikey, customer_name, customer_type):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
@@ -732,24 +716,24 @@ def all_status_project(user_apikey, customer_name, customer_type):
                                     'user_apikey': user_apikey,
                                     'customer_type': customer_type},
                            message_body='')
-
+    rpc_queue.close()
     return value.decode("utf-8")
 
 
 @timeit
-def customer_info(customer_email):
+def customer_info(data):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
                           mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
     value = rpc_queue.call(headers={'operation': 'get_customer_info',
-                                    'customer_email': customer_email},
+                                    'data': data},
                            message_body='')
 
-
+    rpc_queue.close()
     return value.decode("utf-8")
 
 
-
-def save_client_reviews(user_apikey, customer_name, customer_type, body, project_name, review,url_image):
+@timeit
+def save_client_reviews(user_apikey, customer_name, customer_type, body, project_name, review, url_image):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
                           mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
     value = rpc_queue.call(headers={'user_apikey': user_apikey,
@@ -757,16 +741,16 @@ def save_client_reviews(user_apikey, customer_name, customer_type, body, project
                                     'customer_name': customer_name,
                                     'project_name': project_name,
                                     'customer_type': customer_type,
-                                    'review' : review,
-                                    'url_image' : url_image},
+                                    'review': review,
+                                    'url_image': url_image},
                            message_body=body)
+    rpc_queue.close()
     return value.decode('utf-8')
 
 
 @timeit
 def customer_registration(customer_email, customer_type, customer_name, customer_password, first_name, last_name,
-                          phone_number, job,
-                          number_of_staff, plan, cms_if_exist, url_cms,token_cms):
+                          phone_number, job, number_of_staff, plan, cms_if_exist, url_cms, token_cms):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
                           mqueue_port=MESSAGE_QUEUE_PORT,
                           mqueue_user=MESSAGE_QUEUE_USER,
@@ -789,6 +773,7 @@ def customer_registration(customer_email, customer_type, customer_name, customer
                            message_body="")
 
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -809,6 +794,7 @@ def update_profile(customer_email, customer_name, first_name, last_name,
                            message_body="")
 
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -827,6 +813,7 @@ def change_password(customer_email, customer_password, new_password, new_passwor
                            message_body="")
 
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -841,6 +828,7 @@ def forget_password(customer_email):
                            message_body="")
 
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -858,6 +846,7 @@ def contact(first_name, customer_email, subject_of_email, message_email):
                            message_body="")
 
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
@@ -871,6 +860,7 @@ def get_connected_customer_info(customer_email):
 
     return value.decode("utf-8")
 
+
 @timeit
 def get_connected_customer_cms_info(customer_name, customer_type, cms):
     rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
@@ -880,30 +870,28 @@ def get_connected_customer_cms_info(customer_name, customer_type, cms):
                                     'customer_type': customer_type,
                                     'cms': cms},
                            message_body='')
-
+    rpc_queue.close()
     return value.decode("utf-8")
 
 
 def delete_user_data(customer_name, customer_type):
-    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                                 mqueue_port=MESSAGE_QUEUE_PORT,
-                                 mqueue_user=MESSAGE_QUEUE_USER,
-                                 mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
     value = rpc_queue.call(headers={'customer_name': customer_name,
                                     'customer_type': customer_type,
                                     'operation': 'delete_user_data'},
                            message_body="")
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
 
 
 def delete_user_data_from_email(customer_email):
-    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS,
-                                 mqueue_port=MESSAGE_QUEUE_PORT,
-                                 mqueue_user=MESSAGE_QUEUE_USER,
-                                 mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
     value = rpc_queue.call(headers={'customer_email': customer_email,
                                     'operation': 'delete_user_data_from_email'},
                            message_body="")
     value = value.decode('utf-8')
+    rpc_queue.close()
     return value
\ No newline at end of file
